@@ -13,6 +13,7 @@ from astropy.coordinates import SkyCoord
 from astropy.coordinates import Angle
 #from astro_ghost import PS1QueryFunctions as ps1
 from astropy.utils.data import get_pkg_data_filename
+import pkg_resources
 from matplotlib import colors
 from imblearn.under_sampling import RandomUnderSampler
 from scipy import ndimage
@@ -34,7 +35,17 @@ from sklearn import preprocessing
 from imblearn.pipeline import Pipeline
 from rfpimp import *
 
-def loadClassifier():
+def classify(dataML, verbose=True):
+    feature_list, dataML_preprocessed, labels_df2, names = preprocess_dataframe(dataML)
+    dataML_matrix_scaled = preprocessing.scale(dataML_preprocessed)
+    rf = loadClassifier()
+    class_predictions = rf.predict(dataML_matrix_scaled)
+    if verbose:
+        for i in np.arange(len(class_predictions)):
+            print("%s is predicted to be a %s." % (names[i], class_predictions[i]))
+    return class_predictions
+
+def loadClassifier(verbose=True):
     modelName = "BinarySNClassifier.sav"
     stream = pkg_resources.resource_stream(__name__, modelName)
     if verbose:
@@ -332,15 +343,17 @@ def condense_labels(dataML, nclass):
 
 def preprocess_dataframe(dataML, nclass=2):
     dataML.replace(-999, np.nan, inplace=True)
-    trueIDXs = dataML.dropna(subset=['TransientRedshift', 'NED_redshift']).index
-    naIDXs = set(dataML.index) - set(trueIDXs)
 
-    dataML_na = dataML.loc[naIDXs]
-    dataML_nona = dataML.loc[trueIDXs]
+    if 'TransientRedshift' in dataML.columns:
+        trueIDXs = dataML.dropna(subset=['TransientRedshift', 'NED_redshift']).index
+        naIDXs = set(dataML.index) - set(trueIDXs)
 
-    pdiff = np.abs(dataML_nona['TransientRedshift'] - dataML_nona['NED_redshift'])/dataML_nona['TransientRedshift']*100
-    dataML_nona = dataML_nona.loc[pdiff < 5]
-    dataML = pd.concat([dataML_na, dataML_nona], ignore_index=True)
+        dataML_na = dataML.loc[naIDXs]
+        dataML_nona = dataML.loc[trueIDXs]
+
+        pdiff = np.abs(dataML_nona['TransientRedshift'] - dataML_nona['NED_redshift'])/dataML_nona['TransientRedshift']*100
+        dataML_nona = dataML_nona.loc[pdiff < 5]
+        dataML = pd.concat([dataML_na, dataML_nona], ignore_index=True)
 
     #ADDING IN SNR IN TWO BANDS - I AND Z
     dataML["gSNR"] = 1/dataML["gApMagErr"]
@@ -383,7 +396,7 @@ def preprocess_dataframe(dataML, nclass=2):
     dataML = dataML.drop(['rpsfTheta', 'rsky', 'rskyErr', 'rpsfCore'], axis=1)
     dataML = dataML.drop(['gpsfLikelihood', 'rpsfLikelihood', 'ipsfLikelihood', 'zpsfLikelihood','ypsfLikelihood'], axis=1)
     dataML = dataML.drop(['rpsfQf'], axis=1)
-    dataML = dataML.drop(['host_logmass', 'host_logmass_min', 'host_logmass_max','Hubble Residual', 'Transient AltName'],axis=1)
+    #dataML = dataML.drop(['host_logmass', 'host_logmass_min', 'host_logmass_max','Hubble Residual', 'Transient AltName'],axis=1)
     dataML = dataML.drop(['rpsfQfPerfect'], axis=1)
     dataML = dataML.drop(['rApFillFac'], axis=1)
     dataML = dataML.drop(['TransientRA', 'TransientDEC','NED_type', 'NED_name', 'class'], axis=1)
@@ -391,11 +404,10 @@ def preprocess_dataframe(dataML, nclass=2):
     #try dropping NED info now:
     dataML = dataML.drop(['NED_vel', 'NED_mag'], axis=1)
     dataML = dataML.drop(['NED_redshift'], axis=1)
-    dataML = dataML.drop(['TransientRedshift'], axis=1)
-    dataML.drop(['TransientDiscoveryDate',  'TransientDiscoveryMag', 'TransientDiscoveryYear'], axis=1, inplace=True)
+    #dataML = dataML.drop(['TransientRedshift'], axis=1)
+    #dataML.drop(['TransientDiscoveryDate',  'TransientDiscoveryMag', 'TransientDiscoveryYear'], axis=1, inplace=True)
     dataML = dataML.drop(['objID'],axis=1)
 
-    dataML.dropna(subset=dataML.columns.values.tolist().remove("TransientClass"), inplace=True)
     #dataML
 
     dataML = condense_labels(dataML, nclass=nclass)
@@ -405,6 +417,37 @@ def preprocess_dataframe(dataML, nclass=2):
     labels = np.array(labels_df)
     classes = np.unique(labels)
 
+    #order in the same way the classifier training data was labeled
+    dataML = dataML[['gPSFMag', 'gPSFMagErr', 'gApMag', 'gApMagErr', 'gKronMag',
+       'gKronMagErr', 'gpsfMajorFWHM', 'gpsfMinorFWHM', 'gmomentXX',
+       'gmomentXY', 'gmomentYY', 'gmomentR1', 'gmomentRH', 'gPSFFlux',
+       'gPSFFluxErr', 'gApFlux', 'gApFluxErr', 'gApRadius', 'gKronFlux',
+       'gKronFluxErr', 'gKronRad', 'gExtNSigma', 'rPSFMag', 'rPSFMagErr',
+       'rApMag', 'rApMagErr', 'rKronMag', 'rKronMagErr', 'rpsfMajorFWHM',
+       'rpsfMinorFWHM', 'rmomentXX', 'rmomentXY', 'rmomentYY',
+       'rmomentR1', 'rmomentRH', 'rPSFFlux', 'rPSFFluxErr', 'rApFlux',
+       'rApFluxErr', 'rApRadius', 'rKronFlux', 'rKronFluxErr', 'rKronRad',
+       'rExtNSigma', 'iPSFMag', 'iPSFMagErr', 'iApMag', 'iApMagErr',
+       'iKronMag', 'iKronMagErr', 'ipsfMajorFWHM', 'ipsfMinorFWHM',
+       'imomentXX', 'imomentXY', 'imomentYY', 'imomentR1', 'imomentRH',
+       'iPSFFlux', 'iPSFFluxErr', 'iApFlux', 'iApFluxErr', 'iApRadius',
+       'iKronFlux', 'iKronFluxErr', 'iKronRad', 'iExtNSigma', 'zPSFMag',
+       'zPSFMagErr', 'zApMag', 'zApMagErr', 'zKronMag', 'zKronMagErr',
+       'zpsfMajorFWHM', 'zpsfMinorFWHM', 'zmomentXX', 'zmomentXY',
+       'zmomentYY', 'zmomentR1', 'zmomentRH', 'zPSFFlux', 'zPSFFluxErr',
+       'zApFlux', 'zApFluxErr', 'zApRadius', 'zKronFlux', 'zKronFluxErr',
+       'zKronRad', 'zExtNSigma', 'yPSFMag', 'yPSFMagErr', 'yApMag',
+       'yApMagErr', 'yKronMag', 'yKronMagErr', 'ypsfMajorFWHM',
+       'ypsfMinorFWHM', 'ymomentXX', 'ymomentXY', 'ymomentYY',
+       'ymomentR1', 'ymomentRH', 'yPSFFlux', 'yPSFFluxErr', 'yApFlux',
+       'yApFluxErr', 'yApRadius', 'yKronFlux', 'yKronFluxErr', 'yKronRad',
+       'yExtNSigma', 'i-z', 'g-r', 'r-i', 'g-i', 'z-y', 'g-rErr',
+       'r-iErr', 'i-zErr', 'z-yErr', 'gApMag_gKronMag', 'rApMag_rKronMag',
+       'iApMag_iKronMag', 'zApMag_zKronMag', 'yApMag_yKronMag', '7DCD',
+       'dist/DLR', 'dist', 'gSNR', 'rSNR', 'iSNR', 'zSNR', 'ySNR', 'TransientClass']]
+
+    dataML.dropna(axis=0, inplace=True)
+
     feature_list = list(dataML.columns) # Convert to numpy array
 
     dataML_noLabels = dataML.drop('TransientClass', axis=1)
